@@ -93,8 +93,8 @@ class GtkLanguageSelector(LanguageSelectorBase,  SimpleGladeApp):
     # packages that need special translation packs (not covered by
     # the normal langpacks)
     pkg_translations = [
-        ("kdelibs4c2", "language-pack-kde-"),
-        ("libgnome2-0", "language-pack-gnome-"),
+        ("kdelibs-data", "language-pack-kde-"),
+        ("libgnome2-common", "language-pack-gnome-"),
         ("firefox", "mozilla-firefox-locale-"),
         ("mozilla-thunderbird", "mozilla-thunderbird-local-"),
         ("openoffice.org2", "openoffice.org2-l10n-"),
